@@ -1,7 +1,6 @@
 from pydantic import BaseModel, Field
 
-from common_py.model.enums import ContentType
-
+from ..enums import ContentType
 from . import ToolOutput
 
 
