@@ -1,7 +1,6 @@
 from pydantic import BaseModel, Field
 
-from common_py.model import enums
-
+from .. import enums
 from . import ToolOutput
 
 
