@@ -3,6 +3,7 @@ from typing import Any
 from ..client import A79Client
 from ..models.tools import DEFAULT
 from ..models.tools.thoughtspot_models import (
+    ConnectionDetails,
     ConnectionResponse,
     CreateConnectionInput,
     CreateConnectionOutput,
@@ -15,9 +16,11 @@ from ..models.tools.thoughtspot_models import (
     SearchDataResponse,
     SearchMetadataInput,
     SearchMetadataOutput,
+    TableInfo,
 )
 
 __all__ = [
+    "ConnectionDetails",
     "ConnectionResponse",
     "CreateConnectionInput",
     "CreateConnectionOutput",
@@ -30,6 +33,7 @@ __all__ = [
     "SearchDataResponse",
     "SearchMetadataInput",
     "SearchMetadataOutput",
+    "TableInfo",
     "create_connection",
     "create_liveboard",
     "pin_answer",
